Contributing — py_dss_interface 1.0.1 documentation

# Contributing

Contributions are welcome, and they are greatly appreciated! Every little bit helps, and credit will always be given.

## Bug reports

When reporting a bug please include:

> - Your operating system name and version.

> - Any details about your local setup that might be helpful in troubleshooting.

> - Detailed steps to reproduce the bug.

## Documentation improvements

py_dss_interface could always use more documentation, whether as part of the official py_dss_interface docs, in docstrings, or even on the web in blog posts, articles, and such.

## Feature requests and feedback

The best way to send feedback is to file an issue at https://github.com/PauloRadatz/py_dss_interface/issues.

If you are proposing a feature:

- Explain in detail how it would work.

- Keep the scope as narrow as possible, to make it easier to implement.

- Remember that this is a volunteer-driven project, and that code contributions are welcome :)